===============================
pytest-collect-pytest-interinfo
===============================

.. image:: https://img.shields.io/pypi/v/pytest-collect-pytest-interinfo.svg
    :target: https://pypi.org/project/pytest-collect-pytest-interinfo
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/pytest-collect-pytest-interinfo.svg
    :target: https://pypi.org/project/pytest-collect-pytest-interinfo
    :alt: Python versions

.. image:: https://ci.appveyor.com/api/projects/status/github/hackebrot/pytest-collect-pytest-interinfo?branch=master
    :target: https://ci.appveyor.com/project/hackebrot/pytest-collect-pytest-interinfo/branch/master
    :alt: See Build Status on AppVeyor

A simple plugin to use with pytest

----

This `pytest`_ plugin was generated with `Cookiecutter`_ along with `@hackebrot`_'s `cookiecutter-pytest-plugin`_ template.


Features
--------

* TODO


Requirements
------------

* TODO


Installation
------------

You can install "pytest-collect-pytest-interinfo" via `pip`_ from `PyPI`_::

    $ pip install pytest-collect-pytest-interinfo


Usage
-----

* TODO

Contributing
------------
Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.

License
-------

Distributed under the terms of the `BSD-3`_ license, "pytest-collect-pytest-interinfo" is free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`Cookiecutter`: https://github.com/audreyr/cookiecutter
.. _`@hackebrot`: https://github.com/hackebrot
.. _`MIT`: http://opensource.org/licenses/MIT
.. _`BSD-3`: http://opensource.org/licenses/BSD-3-Clause
.. _`GNU GPL v3.0`: http://www.gnu.org/licenses/gpl-3.0.txt
.. _`Apache Software License 2.0`: http://www.apache.org/licenses/LICENSE-2.0
.. _`cookiecutter-pytest-plugin`: https://github.com/pytest-dev/cookiecutter-pytest-plugin
.. _`file an issue`: https://github.com/hackebrot/pytest-collect-pytest-interinfo/issues
.. _`pytest`: https://github.com/pytest-dev/pytest
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.org/project/pip/
.. _`PyPI`: https://pypi.org/project
